@@ -174,11 +174,11 @@ void flog(int level, const char *format, ...)
  * Libcgroup logging callback. It must translate libcgroup log levels
  * to cgrulesengd native (=syslog).
  */
-void flog_cgroup(void *userdata, int cgroup_level, const char *format, va_list ap)
+void flog_cgroup(void *userdata, int cgrp_level, const char *format, va_list ap)
 {
 	int level = 0;
 
-	switch (cgroup_level) {
+	switch (cgrp_level) {
 	case CGROUP_LOG_ERROR:
 		level = LOG_ERR;
 		break;
@@ -223,6 +223,7 @@ static int cgre_store_parent_info(pid_t pid)
 	if (array_pi.index >= array_pi.num_allocation) {
 		int alloc = array_pi.num_allocation + NUM_PER_REALLOCATIOM;
 		void *new_array = realloc(array_pi.parent_info, sizeof(info) * alloc);
+
 		if (!new_array) {
 			flog(LOG_WARNING, "Failed to allocate memory\n");
 			return 1;
@@ -314,6 +315,7 @@ static int cgre_store_unchanged_process(pid_t pid, int flags)
 	if (array_unch.index >= array_unch.num_allocation) {
 		int alloc = array_unch.num_allocation + NUM_PER_REALLOCATIOM;
 		void *new_array = realloc(array_unch.proc, sizeof(unchanged_pid_t) * alloc);
+
 		if (!new_array) {
 			flog(LOG_WARNING, "Failed to allocate memory\n");
 			return 1;
@@ -565,7 +567,7 @@ static int cgre_receive_netlink_msg(int sk_nl)
 	from_nla_len = sizeof(from_nla);
 	recv_len = recvfrom(sk_nl, buff, sizeof(buff), 0, (struct sockaddr *)&from_nla,
 			    &from_nla_len);
-	if (recv_len == ENOBUFS) {
+	if (recv_len == -1 && errno == ENOBUFS) {
 		flog(LOG_ERR, "ERROR: NETLINK BUFFER FULL, MESSAGE DROPPED!\n");
 		return 0;
 	}
@@ -801,7 +803,7 @@ close_and_exit:
 /**
  * Start logging. Opens syslog and/or log file and sets log level.
  *	@param logp Path of the log file, NULL if no log file was specified
- *	@param logf Syslog facility, NULL if no facility was specified
+ *	@param logf syslog facility, NULL if no facility was specified
  *	@param logv Log verbosity, 1 is the default, 0 = no logging, 4 = everything
  */
 static void cgre_start_log(const char *logp, int logf, int logv)
@@ -867,7 +869,7 @@ static void cgre_start_log(const char *logp, int logf, int logv)
  * parent process.  Note too that stdout, stdin, and stderr are closed in
  * daemon mode, and a file descriptor for a log file is opened.
  *	@param logp Path of the log file, NULL if no log file was specified
- *	@param logf Syslog facility, 0 if no facility was specified
+ *	@param logf syslog facility, 0 if no facility was specified
  *	@param daemon False to turn off daemon mode (no fork, leave FDs open)
  *	@param logv Log verbosity, 1 is the default, 0 = no logging, 5 = everything
  *	@return 0 on success, > 0 on error
@@ -1040,7 +1042,7 @@ int main(int argc, char *argv[])
 	/* Patch to the log file */
 	const char *logp = NULL;
 
-	/* Syslog facility */
+	/* syslog facility */
 	int facility = 0;
 
 	/* Verbose level */
@@ -1276,7 +1278,7 @@ int main(int argc, char *argv[])
 
 	flog(LOG_INFO, "Started the CGroup Rules Engine Daemon.\n");
 
-	/* We loop endlesly in this function, unless we encounter an error. */
+	/* We loop endlessly in this function, unless we encounter an error. */
 	ret =  cgre_create_netlink_socket_process_msg();
 
 finished:
