@@ -19,10 +19,7 @@ CGNAME = '014cgget'
 
 
 def prereqs(config):
-    result = consts.TEST_PASSED
-    cause = None
-
-    return result, cause
+    pass
 
 
 def setup(config):
@@ -65,7 +62,6 @@ def test(config):
     if 'cpuset.cpus' not in out:
         result = consts.TEST_FAILED
         cause = 'Failed to find cpuset settings in output\n{}'.format(out)
-        return result, cause
 
     return result, cause
 
@@ -85,10 +81,7 @@ def teardown(config):
 
 
 def main(config):
-    [result, cause] = prereqs(config)
-    if result != consts.TEST_PASSED:
-        return [result, cause]
-
+    prereqs(config)
     setup(config)
     [result, cause] = test(config)
     teardown(config)
