@@ -35,8 +35,8 @@ class Process(object):
 
     @staticmethod
     def __infinite_loop(config, sleep_time=1):
-        cmd = ["/usr/bin/perl",
-               "-e",
+        cmd = ['/usr/bin/perl',
+               '-e',
                "'while(1){{sleep({})}};'".format(sleep_time)
                ]
 
@@ -53,8 +53,8 @@ class Process(object):
     @staticmethod
     def __cgexec_infinite_loop(config, controller, cgname, sleep_time=1,
                                ignore_systemd=False, replace_idle=False):
-        cmd = ["/usr/bin/perl",
-               "-e",
+        cmd = ['/usr/bin/perl',
+               '-e',
                "'while(1){{sleep({})}};'".format(sleep_time)
                ]
 
@@ -70,20 +70,28 @@ class Process(object):
         # get the PID of the newly spawned infinite loop
         cmd = (
                 "ps x | grep perl | grep 'sleep({})' | awk '{{print $1}}'"
-                "".format(sleep_time)
+                ''.format(sleep_time)
               )
 
-        if config.args.container:
-            pid = config.container.run(cmd, shell_bool=True)
-        else:
-            pid = Run.run(cmd, shell_bool=True)
+        for i in range(3):
+            try:
+                if config.args.container:
+                    pid = config.container.run(cmd, shell_bool=True)
+                    break
+                else:
+                    pid = Run.run(cmd, shell_bool=True)
+                    break
+            except RunError:
+                # On some setups, lxc will throw Signal 21 (TTIN) caught by ps (3.3.17).
+                # Retrying the request usually works.
+                pass
 
-            for _pid in pid.splitlines():
-                self.children_pids.append(int(_pid))
+        for _pid in pid.splitlines():
+            self.children_pids.append(int(_pid))
 
-            if pid.find('\n') >= 0:
-                # The second pid in the list contains the actual perl process
-                pid = pid.splitlines()[1]
+        if pid.find('\n') >= 0:
+            # The second pid in the list contains the actual perl process
+            pid = pid.splitlines()[1]
 
         if pid == '' or int(pid) <= 0:
             raise ValueError(
